@@ -1,5 +1,6 @@
 import numpy as np
 from ..utils import dprint
+from pathlib import Path
 
 def tryReadImage(path:str, imgLib:str="opencv", count:int=5) -> np.ndarray:
 	assert imgLib in ("opencv", "PIL", "pillow", "lycon")
@@ -10,6 +11,8 @@ def tryReadImage(path:str, imgLib:str="opencv", count:int=5) -> np.ndarray:
 	elif imgLib == "lycon":
 		from .libs.lycon import readImage
 
+	path = str(path) if isinstance(path, Path) else path
+
 	i = 0
 	while True:
 		try:
